# Generated by roxygen2: do not edit by hand

S3method(assumptions,exp_kofn)
S3method(assumptions,wei_kofn)
S3method(fit,exp_kofn)
S3method(fit,wei_kofn)
S3method(hess_loglik,exp_kofn)
S3method(hess_loglik,wei_kofn)
S3method(loglik,exp_kofn)
S3method(loglik,wei_kofn)
S3method(ncomponents,kofn)
S3method(print,kofn)
S3method(rdata,exp_kofn)
S3method(rdata,wei_kofn)
S3method(score,exp_kofn)
S3method(score,wei_kofn)
export(F_sys_exp)
export(S_sys_exp)
export(assumptions)
export(compare_fisher_info)
export(dfr_exponential)
export(dfr_weibull)
export(fit)
export(fit_scheme1)
export(hess_loglik)
export(ie_expand)
export(is_kofn)
export(kofn)
export(loglik)
export(loglik_masked)
export(loglik_scheme1)
export(ncomponents)
export(observe_exact)
export(observe_interval_censor)
export(observe_left_censor)
export(observe_mixture)
export(observe_periodic)
export(observe_right_censor)
export(rdata)
export(rdata_masked)
export(rdata_scheme1)
export(score)
export(solve_mle)
export(trunc_log_moment_vec)
export(trunc_pow_moment)
export(trunc_pow_moment_vec)
export(w_j_exact)
export(w_j_integral)
importFrom(dist.structure,ncomponents)
importFrom(flexhaz,dfr_exponential)
importFrom(flexhaz,dfr_weibull)
importFrom(generics,fit)
importFrom(likelihood.model,assumptions)
importFrom(likelihood.model,hess_loglik)
importFrom(likelihood.model,loglik)
importFrom(likelihood.model,rdata)
importFrom(likelihood.model,score)
importFrom(numDeriv,grad)
importFrom(numDeriv,hessian)
importFrom(stats,coef)
importFrom(stats,density)
importFrom(stats,pgamma)
importFrom(stats,runif)
